@@ -13,14 +13,18 @@
 #    under the License.
 
 from django.conf import urls
-
 from muranodashboard.images import views
 
 
-urlpatterns = [
-    urls.url(r'^$', views.MarkedImagesView.as_view(), name='index'),
+urlpatterns = urls.patterns(
+    '',
+    urls.url(r'^$', views.MarkedImagesView.as_view(),
+             name='index'),
+
     urls.url(r'^mark_image$', views.MarkImageView.as_view(),
              name='mark_image'),
+
     urls.url(r'^remove_metadata$', views.MarkedImagesView.as_view(),
              name='remove_metadata'),
-]
+
+)
